@@ -46,6 +46,9 @@
 #include "config.h"
 #endif
 
+#include <string.h>
+#include <stdio.h>
+
 #include "xf86Version.h"
 #if XF86_VERSION_CURRENT >= XF86_VERSION_NUMERIC(3,9,0,0,0)
 #define XFREE86_V4
@@ -55,7 +58,6 @@
 #include "misc.h"
 #include "xf86.h"
 #if !defined(DGUX)
-#include "xf86_ansic.h"
 #endif
 #include "xf86_OSproc.h"
 #include "xf86Xinput.h"
@@ -1873,7 +1875,7 @@ static XF86ModuleVersionInfo version_rec = {
   MODINFOSTRING1,
   MODINFOSTRING2,
   XORG_VERSION_CURRENT,
-  1, 0, 0,
+  PACKAGE_VERSION_MAJOR, PACKAGE_VERSION_MINOR, PACKAGE_VERSION_PATCHLEVEL,
   ABI_CLASS_XINPUT,
   ABI_XINPUT_VERSION,
   MOD_CLASS_XINPUT,
